Enum easycurses::Color
[−]
[src]
pub enum Color {
Black,
Red,
Green,
Yellow,
Blue,
Magenta,
Cyan,
White,
}The curses color constants.
Curses supports eight different colors. Each character cell has one "color pair" set which is a foreground and background pairing. Note that a cell can also be "bold", which might display as differnet colors on some terminals.
Variants
BlackRedGreenYellowBlueMagentaCyanWhiteMethods
impl Color[src]
fn color_iterator() -> Cloned<Iter<'static, Color>>
Provides a handy Iterator over all of the Color values.